# DID Table (0xF180–0xF19F)

| DID | Name | Description |
|---|---|---|
| 0xF180 | BootSoftwareIdentification | Boot software ID |
| 0xF181 | ApplicationSoftwareIdentification | Application software ID |
| 0xF182 | ApplicationDataIdentification | Application data ID |
| 0xF183 | BootSoftwareVersionNumber | Boot software version |
| 0xF184 | ApplicationSoftwareVersionNumber | Application software version |
| 0xF185 | ApplicationDataVersionNumber | Application data version |
| 0xF186 | ActiveDiagnosticSession | Active session |
| 0xF187 | VehicleManufacturerSparePartNumber | Spare part number |
| 0xF188 | VehicleManufacturerECUSoftwareNumber | ECU software number |
| 0xF189 | VehicleManufacturerECUSoftwareVersionNumber | ECU software version |
| 0xF18A | SystemSupplierIdentifier | Supplier identifier |
| 0xF18B | ECUManufacturingDate | ECU manufacturing date |
| 0xF18C | ECUSerialNumber | ECU serial number |
| 0xF18D | SupportedFunctionalUnits | Supported functional units |
| 0xF18E | VehicleManufacturerKitAssemblyPartNumber | Kit assembly part number |
| 0xF18F | ISOSoftwareIdentification | ISO software ID |
| 0xF190 | VIN | Vehicle Identification Number |
| 0xF191 | VehicleManufacturerECUHardwareNumber | ECU hardware number |
| 0xF192 | VehicleManufacturerECUHardwareVersionNumber | ECU hardware version |
| 0xF193 | SystemSupplierECUHardwareNumber | Supplier ECU hardware number |
| 0xF194 | SystemSupplierECUHardwareVersionNumber | Supplier ECU hardware version |
| 0xF195 | SystemSupplierECUSoftwareNumber | Supplier ECU software number |
| 0xF196 | SystemSupplierECUSoftwareVersionNumber | Supplier ECU software version |
| 0xF197 | ExhaustRegulationOrTypeApprovalNumber | Type approval number |
| 0xF198 | SystemNameOrEngineType | System/engine type |
| 0xF199 | RepairShopCodeOrTesterSerialNumber | Repair shop code/tester serial |
| 0xF19A | ProgrammingDate | Programming date |
| 0xF19B | CalibrationDate | Calibration date |
| 0xF19C | CalibrationEquipment | Calibration equipment |
| 0xF19D | CalibrationSoftwareIdentification | Calibration software ID |
| 0xF19E | CalibrationSoftwareVersionNumber | Calibration software version |
| 0xF19F | ProgrammingStationIdentifier | Programming station ID |
